@@ -1,11 +1,11 @@
-#' Clean an eBird data file
+#' Clean an eBird data file (Deprecated)
 #'
-#' Some rows in the eBird Basic Dataset (EBD) may have an incorrect number of
-#' columns, often resulting from tabs embedded in the comments field. This
-#' function drops these problematic records. **Note that this function typically
-#' takes at least 3 hours to run on the full dataset**
+#' This function is no longer required by current versions of the eBird Basic 
+#' Dataset (EBD).
 #'
-#' @param f_in character; input file.
+#' @param f_in character; input file. If file is not found as specified, it will 
+#'   be looked for in the directory specified by the `EBD_PATH` environment 
+#'   variable.
 #' @param f_out character; output file.
 #' @param sep character; the input field separator, the basic dataset is tab
 #'   separated by default. Must only be a single character and space delimited
@@ -16,15 +16,7 @@
 #'   increase the file size, yet are rarely valuable for analytical
 #'   applications, so may be removed. Setting this argument to `TRUE` can lead
 #'   to a significant reduction in file size.
-#' @param overwrite logical; overwrite output file if it already exists
-#'
-#' @details
-#'
-#' This function can clean a basic dataset file or a sampling file.
-#'
-#' Calling this function requires that the command line utility AWK is
-#' installed. Linux and Mac machines should have AWK by default, Windows users
-#' will likely need to install [Cygwin](https://www.cygwin.com).
+#' @param overwrite logical; overwrite output file if it already exists.
 #'
 #' @return If AWK ran without errors, the output filename is returned, however,
 #'   if an error was encountered the exit code is returned.
@@ -33,37 +25,30 @@
 #' @examples
 #' \dontrun{
 #' # get the path to the example data included in the package
-#' # in practice, provide path to ebd, e.g. f <- "data/ebd_relFeb-2018.txt
-#' f <- system.file("extdata/ebd-sample_messy.txt", package = "auk")
+#' f <- system.file("extdata/ebd-sample.txt", package = "auk")
 #' # output to a temp file for example
 #' # in practice, provide path to output file
 #' # e.g. f_out <- "output/ebd_clean.txt"
 #' f_out <- tempfile()
 #'
 #' # clean file to remove problem rows
+#' # note: this function is deprecated and no longer does anything
 #' auk_clean(f, f_out)
-#' # number of lines in input
-#' length(readLines(f))
-#' # number of lines in output
-#' length(readLines(f_out))
-#'
-#' # note that the extra blank column has also been removed
-#' ncol(read.delim(f, nrows = 5, quote = ""))
-#' ncol(read.delim(f_out, nrows = 5, quote = ""))
 #' }
 auk_clean <- function(f_in, f_out, sep = "\t", remove_text = FALSE, 
                       overwrite = FALSE) {
+  .Deprecated()
   # checks
-  awk_path <- auk_getpath()
+  awk_path <- auk_get_awk_path()
   if (is.na(awk_path)) {
     stop("auk_clean() requires a valid AWK install.")
   }
   assertthat::assert_that(
-    file.exists(f_in),
     assertthat::is.string(sep), nchar(sep) == 1, sep != " ",
     assertthat::is.flag(remove_text),
     assertthat::is.flag(overwrite)
   )
+  f_in <- ebd_file(f_in)
   # check output file
   if (!dir.exists(dirname(f_out))) {
     stop("Output directory doesn't exist.")
@@ -127,7 +112,7 @@ BEGIN {
   # remove end of line tab
   sub(/\t$/, \"\", $0)
   # only keep rows with correct number of records
-  if (NF == ${ncols} || NR == 1) {
+  if (NF != ${ncols} || NR == 1) {
     print ${print_cols}
   }
 }
